@@ -1,14 +1,16 @@
 package inc::latest;
+
+use if $] >= 5.019, 'deprecate';
+
 use strict;
 use vars qw($VERSION);
-$VERSION = '0.4004';
+$VERSION = '0.4006';
 $VERSION = eval $VERSION;
 
 use Carp;
 use File::Basename  ();
 use File::Spec      ();
 use File::Path      ();
-use IO::File        ();
 use File::Copy      ();
 
 # track and return modules loaded by inc::latest
@@ -43,7 +45,7 @@ sub write {
 
   # write inc/latest.pm
   File::Path::mkpath( $where );
-  my $fh = IO::File->new( File::Spec->catfile($where,'latest.pm'), "w" );
+  open my $fh, '>', File::Spec->catfile($where,'latest.pm');
   print {$fh} "# This stub created by inc::latest $VERSION\n";
   print {$fh} <<'HERE';
 package inc::latest;
